@@ -30,16 +30,16 @@
 
 class QString;
 
-class ApplicationListModel;
+namespace KWayland
+{
+namespace Client
+{
+class PlasmaWindowManagement;
+class PlasmaWindow;
+}
+}
 
-struct ApplicationData {
-    QString name;
-    QString icon;
-    QString storageId;
-    QString entryPath;
-    int location = 0; //FIXME
-    bool startupNotify = true;
-};
+class ApplicationListModel;
 
 class ApplicationListModel : public QAbstractListModel {
     Q_OBJECT
@@ -56,6 +56,16 @@ public:
     };
     Q_ENUM(LauncherLocation)
 
+    struct ApplicationData {
+        QString name;
+        QString icon;
+        QString storageId;
+        QString entryPath;
+        LauncherLocation location = LauncherLocation::Grid;
+        bool startupNotify = true;
+        KWayland::Client::PlasmaWindow *window = nullptr;
+    };
+
     enum Roles {
         ApplicationNameRole = Qt::UserRole + 1,
         ApplicationIconRole,
@@ -63,7 +73,8 @@ public:
         ApplicationEntryPathRole,
         ApplicationOriginalRowRole,
         ApplicationStartupNotifyRole,
-        ApplicationLocationRole
+        ApplicationLocationRole,
+        ApplicationRunningRole
     };
 
     ApplicationListModel(HomeScreen *parent = nullptr);
@@ -95,6 +106,9 @@ public:
 
     Q_INVOKABLE void loadApplications();
 
+    Q_INVOKABLE void setMinimizedDelegate(int row, QQuickItem *delegate);
+    Q_INVOKABLE void unsetMinimizedDelegate(int row, QQuickItem *delegate);
+
 public Q_SLOTS:
      void sycocaDbChanged(const QStringList &change);
 
@@ -104,8 +118,11 @@ Q_SIGNALS:
     void maxFavoriteCountChanged();
 
 private:
+    void initWayland();
+
     QList<ApplicationData> m_applicationList;
 
+    KWayland::Client::PlasmaWindowManagement *m_windowManagement = nullptr;
     HomeScreen *m_homeScreen = nullptr;
     int m_maxFavoriteCount = 0;
     QStringList m_appOrder;
